@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array;
-$List::Objects::WithUtils::Role::Array::VERSION = '2.027001';
+$List::Objects::WithUtils::Role::Array::VERSION = '2.027002';
 use strictures 2;
 
 use Carp            ();
@@ -614,7 +614,7 @@ sub squished {
       # .. or not:
       $last[0] = $_; CORE::push @res, $_; next ITEM
     } elsif (!defined $last[0]) {
-      # Previous was an undef:
+      # Previous was an undef (but this isn't)
       $last[0] = $_; CORE::push @res, $_; next ITEM
     }
     next ITEM if $_ eq $last[0];
@@ -1494,6 +1494,37 @@ given sub returns unique values.
 
 Uses L<List::UtilsBy::XS> if available; falls back to L<List::UtilsBy> if not.
 
+=head1 NOTES FOR CONSUMERS
+
+If creating your own consumer of this role, some extra effort is required to
+make C<$a> and C<$b> work in sort statements without warnings; an example with
+a custom exported constructor (and junction support) might look something like:
+
+  package My::Custom::Array;
+  use strictures 2;
+  require Role::Tiny;
+  Role::Tiny->apply_roles_to_package( __PACKAGE__,
+    qw/
+      List::Objects::WithUtils::Role::Array
+      List::Objects::WithUtils::Role::Array::WithJunctions
+      My::Custom::Array::Role
+     /
+  );
+
+  use Exporter ();
+  our @EXPORT = 'myarray';
+  sub import {
+    # touch $a/$b in caller to avoid 'used only once' warnings:
+    my $pkg = caller;
+    { no strict 'refs';
+      ${"${pkg}::a"} = ${"${pkg}::a"};
+      ${"${pkg}::b"} = ${"${pkg}::b"};
+    }
+    goto &Exporter::import
+  }
+
+  sub myarray { __PACKAGE__->new(@_) }
+
 =head1 SEE ALSO
 
 L<List::Objects::WithUtils>
