@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Hash;
-$List::Objects::WithUtils::Role::Hash::VERSION = '2.027001';
+$List::Objects::WithUtils::Role::Hash::VERSION = '2.027002';
 use strictures 2;
 
 use Module::Runtime ();
@@ -99,10 +99,26 @@ sub get_path {
 =cut
 
 { no warnings 'once'; *slice = *sliced; }
-sub sliced {
-  blessed_or_pkg($_[0])->new(
-    map {; exists $_[0]->{$_} ? ( $_ => $_[0]->{$_} ) : () } @_[1 .. $#_]
-  )
+{ local $@;
+  if ($] >= 5.020) {
+    eval q[
+      sub sliced {
+        blessed_or_pkg($_[0])->new( 
+          %{ $_[0] }{ grep {; exists $_[0]->{$_} } @_[1 .. $#_] } 
+        )
+      }
+    ];
+  } else {
+    eval q[
+      sub sliced {
+        blessed_or_pkg($_[0])->new(
+          map {; exists $_[0]->{$_} ? ($_ => $_[0]->{$_}) : () } 
+            @_[1 .. $#_]
+        )
+      }
+    ];
+  }
+  die "installing sub 'sliced' died: $@" if $@;
 }
 
 sub set {
@@ -572,10 +588,14 @@ C<$a> and C<$b>, respectively.
 
   my $newhash = $hash->sliced(@keys);
 
-Returns a new hash object built from the specified set of keys (see L</get> if
-you only need the values.)
+Returns a new hash object built from the specified set of keys and their
+respective values.
 
-If a given key is not found in the hash, it is omitted from the result.
+If a given key is not found in the hash, it is omitted from the result (this
+is different than C<perl-5.20+> hash slice syntax, which sets unknown keys to
+C<undef> in the slice).
+
+If you only need the values, see L</get>.
 
 =head2 Methods that compare hashes
 
@@ -595,6 +615,35 @@ The opposite of L</intersection>; returns the list of keys that are not common
 to all given hash-type objects (including the invocant) as an L</array_type>
 object.
 
+=head1 NOTES FOR CONSUMERS
+
+If creating your own consumer of this role, some extra effort is required to
+make C<$a> and C<$b> work in sort statements without warnings; an example with
+a custom exported constructor might look something like:
+
+  package My::Custom::Hash;
+  use strictures 2;
+  require Role::Tiny;
+  Role::Tiny->apply_roles_to_package( __PACKAGE__,
+    qw/
+      List::Objects::WithUtils::Role::Hash
+      My::Custom::Hash::Role
+    /
+  );
+
+  use Exporter ();
+  our @EXPORT = 'myhash';
+  sub import {
+    my $pkg = caller;
+    { no strict 'refs';
+      ${"${pkg}::a"} = ${"${pkg}::a"};
+      ${"${pkg}::b"} = ${"${pkg}::b"};
+    }
+    goto &Exporter::import
+  }
+
+  sub myhash { __PACKAGE__->new(@_) }
+
 =head1 SEE ALSO
 
 L<List::Objects::WithUtils>
